@@ -544,7 +544,7 @@ class RedisRoot:
                         value = real_value
                         allowed_redis_params[redis_field_param_name] = value
                     elif django_field_param_name == 'remote_field':
-                        redis_field_param_name = 'model'
+                        redis_field_param_name = 'redis_model'
                         if value is not None:
                             value = value.model
                             if value is not None:
@@ -806,7 +806,7 @@ class RedisRoot:
                 else:
                     field.value = None
                     cleaned_value = field.clean()
-                    allowed = self._filter_field_name(field_name, cleaned_value, filters)
+                    allowed = self._filter_field_name(model, field_name, cleaned_value, filters)
                     checked_instances[instance_id][field_name] = {
                         'value': cleaned_value,
                         'allowed': allowed
@@ -859,15 +859,35 @@ class RedisRoot:
                 allowed = False
         return allowed
 
-    def _filter_field_name(self, field_name, value, raw_filters):
+    def _split_filtering(self, redis_model, filter_param):
+        filter_field_name, filter_type = filter_param, 'exact'
+        if '__' in filter_param:
+            filter_param_split = filter_param.split('__')
+            fields_to_filter = filter_param_split[:-1]
+            filter_type = filter_param_split[-1]
+        else:
+            fields_to_filter = [filter_field_name]
+        return fields_to_filter, filter_type
+
+    def _filter(self, value, fields_to_filter, filter_type, filter_by):
+        for field_to_filter in fields_to_filter:
+            try:
+                value = value[field_to_filter]
+            except KeyError as ex:
+                raise Exception(f'KeyError: {ex}\n'
+                                f'Info: {field_to_filter = }, {value = }\n'
+                                f'Maybe: deep filtering is not included on this model')
+        allowed = self._filter_value(value, filter_type, filter_by)
+        return allowed
+
+    def _filter_field_name(self, redis_model, field_name, value, raw_filters):
         allowed_list = [True]
         for filter_param in raw_filters.keys():
             filter_by = raw_filters[filter_param]
-            filter_field_name, filter_type = filter_param, 'exact'
-            if '__' in filter_param:
-                filter_field_name, filter_type = filter_param.split('__')
-            if field_name == filter_field_name:
-                allowed_list.append(self._filter_value(value, filter_type, filter_by))
+            fields_to_filter, filter_type = self._split_filtering(redis_model, filter_param)
+            if field_name == fields_to_filter[0]:
+                fields_to_filter = fields_to_filter[1:]
+                allowed_list.append(self._filter(value, fields_to_filter, filter_type, filter_by))
         allowed = all(allowed_list)
         return allowed
 
@@ -885,13 +905,13 @@ class RedisRoot:
                 instances[instance_id][field_name] = value
         return instances
 
-    def _get_all_stored_model_instances(self, model, filters=None):
-        model_name = model.__name__
-        instances = self._get_instances_by_key(f'{self.prefix}:{model_name}:*')
+    def _get_all_stored_model_instances(self, redis_model, filters=None):
+        redis_model_name = redis_model.__name__
+        instances = self._get_instances_by_key(f'{self.prefix}:{redis_model_name}:*')
         instances_with_allowed = {}
         for instance_id, instance_fields in instances.items():
             for field_name, field_value in instance_fields.items():
-                allowed = self._filter_field_name(field_name, field_value, filters)
+                allowed = self._filter_field_name(redis_model, field_name, field_value, filters)
                 if instance_id not in instances_with_allowed.keys():
                     instances_with_allowed[instance_id] = {}
                 instances_with_allowed[instance_id][field_name] = {
@@ -914,12 +934,12 @@ class RedisRoot:
                 }
         return instances
 
-    def _get_all_redis_model_instances(self, model, filters=None):
+    def _get_all_redis_model_instances(self, redis_model, filters=None):
         if filters is None:
             filters = {}
-        instances_with_allowed = self._get_all_stored_model_instances(model, filters)
+        instances_with_allowed = self._get_all_stored_model_instances(redis_model, filters)
         if self.save_consistency:
-            instances_with_allowed = self._check_fields_existence(model, instances_with_allowed, filters)
+            instances_with_allowed = self._check_fields_existence(redis_model, instances_with_allowed, filters)
         instances = self._get_instances_from_instances_with_allowed(instances_with_allowed)
         return instances
     
@@ -928,7 +948,7 @@ class RedisRoot:
             redis_model = self.get_or_create_redis_model_from_django_model(django_model)
             return redis_model
         else:
-            raise Exception(f'Django model {django_model} is not registered in redis cache')
+            raise Exception(f'Django redis_model {django_model} is not registered in redis cache')
 
     def get_by_redis_model(self, redis_model, return_dict=False, **filters):
         instances = self._get_all_redis_model_instances(redis_model, filters)
